@@ -399,3 +399,12 @@ class WhenTestingPKCS11(utils.BaseTestCase):
     def test_check_error_with_token_error(self):
         self.assertRaises(exception.P11CryptoTokenException,
                           self.pkcs11._check_error, 0xe0)
+
+    def test_converting_unicode_to_bytes(self):
+        self.assertEqual(b'foo', pkcs11._to_bytes(u'foo'))
+
+    def test_converting_default_str_type_to_bytes(self):
+        self.assertEqual(b'foo', pkcs11._to_bytes('foo'))
+
+    def test_converting_bytes_to_bytes(self):
+        self.assertEqual(b'foo', pkcs11._to_bytes(b'foo'))
