@@ -49,6 +49,8 @@ def mock_pecan_request(test_instance, host=None):
     mock_req = patcher_obj.start()
     test_instance.addCleanup(patcher_obj.stop)
     mock_req.url = host
+    mock_req.environ = os.environ.copy()
+    mock_req.application_url = host
 
 
 @contextmanager
@@ -66,7 +68,7 @@ class BarbicanAPIBaseTestCase(oslotest.BaseTestCase):
         context = barbican.context.RequestContext(
             roles=roles,
             user=user,
-            project=project_id,
+            project_id=project_id,
             is_admin=is_admin
         )
         context.policy_enforcer = policy_enforcer
@@ -609,20 +611,6 @@ def get_tomorrow_timestamp():
     return tomorrow.isoformat()
 
 
-def string_to_datetime(datetimestring, date_formats=None):
-    date_formats = date_formats or [
-        '%Y-%m-%d %H:%M:%S', '%Y-%m-%d %H:%M:%S.%f', '%Y-%m-%dT%H:%M:%S.%fZ',
-        '%Y-%m-%dT%H:%M:%S.%f', "%Y-%m-%dT%H:%M:%SZ", "%Y-%m-%dT%H:%M:%S"]
-
-    for dateformat in date_formats:
-        try:
-            return datetime.datetime.strptime(datetimestring, dateformat)
-        except ValueError:
-            continue
-    else:
-        raise
-
-
 def get_id_from_ref(ref):
     """Returns id from reference."""
     ref_id = None
@@ -675,5 +663,13 @@ def is_kmip_enabled():
     return os.environ.get('KMIP_PLUGIN_ENABLED') is not None
 
 
+def is_vault_enabled():
+    return os.environ.get('VAULT_PLUGIN_ENABLED') is not None
+
+
+def is_pkcs11_enabled():
+    return os.environ.get('PKCS11_PLUGIN_ENABLED') is not None
+
+
 class DummyClassForTesting(object):
     pass
